==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/NicIPSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.IPAddressAllocationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the network interface ip settings.
 * @property allocationMethod Gets or sets the nic allocation method.
 * @property dnsServers Gets or sets the dns servers.
 * @property gateway Gets or sets the gateway.
 * @property ipAddress Gets or sets the ip address for the nic.
 * @property subnetMask Gets or sets the mask.
 */
public data class NicIPSettingsArgs(
    public val allocationMethod: Output<Either<String, IPAddressAllocationMethod>>? = null,
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<List<String>>? = null,
    public val ipAddress: Output<String>? = null,
    public val subnetMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs.builder()
            .allocationMethod(
                allocationMethod?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipAddress(ipAddress?.applyValue({ args0 -> args0 }))
            .subnetMask(subnetMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NicIPSettingsArgs].
 */
@PulumiTagMarker
public class NicIPSettingsArgsBuilder internal constructor() {
    private var allocationMethod: Output<Either<String, IPAddressAllocationMethod>>? = null

    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<List<String>>? = null

    private var ipAddress: Output<String>? = null

    private var subnetMask: Output<String>? = null

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("iprtqlwuedgthrtb")
    public suspend fun allocationMethod(`value`: Output<Either<String, IPAddressAllocationMethod>>) {
        this.allocationMethod = value
    }

    /**
     * @param value Gets or sets the dns servers.
     */
    @JvmName("qoheluvmoxpiyseo")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("friqnppruulbdivl")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the dns servers.
     */
    @JvmName("xeomgpvobkenpbrf")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Gets or sets the gateway.
     */
    @JvmName("ttgbhcayvloaatld")
    public suspend fun gateway(`value`: Output<List<String>>) {
        this.gateway = value
    }

    @JvmName("tddnjlkbkwicnaxn")
    public suspend fun gateway(vararg values: Output<String>) {
        this.gateway = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the gateway.
     */
    @JvmName("dxateqhtkvamchnf")
    public suspend fun gateway(values: List<Output<String>>) {
        this.gateway = Output.all(values)
    }

    /**
     * @param value Gets or sets the ip address for the nic.
     */
    @JvmName("mcvgypeeljhlncfa")
    public suspend fun ipAddress(`value`: Output<String>) {
        this.ipAddress = value
    }

    /**
     * @param value Gets or sets the mask.
     */
    @JvmName("cuefcretpfrfluie")
    public suspend fun subnetMask(`value`: Output<String>) {
        this.subnetMask = value
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("jybjlegarulmxfvs")
    public suspend fun allocationMethod(`value`: Either<String, IPAddressAllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("eviovhxusktysvtj")
    public fun allocationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAddressAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("phrgtxecqagbddss")
    public fun allocationMethod(`value`: IPAddressAllocationMethod) {
        val toBeMapped = Either.ofRight<String, IPAddressAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the dns servers.
     */
    @JvmName("higqeydtrfsbliwg")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Gets or sets the dns servers.
     */
    @JvmName("mqkrbwduesmapyrb")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Gets or sets the gateway.
     */
    @JvmName("kinphudxxfhjofby")
    public suspend fun gateway(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param values Gets or sets the gateway.
     */
    @JvmName("cgslajewedlbfrbf")
    public suspend fun gateway(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Gets or sets the ip address for the nic.
     */
    @JvmName("pxurevukctcwomce")
    public suspend fun ipAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddress = mapped
    }

    /**
     * @param value Gets or sets the mask.
     */
    @JvmName("rkuuoiwjayyuoqdy")
    public suspend fun subnetMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMask = mapped
    }

    internal fun build(): NicIPSettingsArgs = NicIPSettingsArgs(
        allocationMethod = allocationMethod,
        dnsServers = dnsServers,
        gateway = gateway,
        ipAddress = ipAddress,
        subnetMask = subnetMask,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/NicIPSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.IPAddressAllocationMethod
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines the network interface ip settings.
 * @property allocationMethod Gets or sets the nic allocation method.
 * @property dnsServers Gets or sets the dns servers.
 * @property gateway Gets or sets the gateway.
 * @property ipAddress Gets or sets the ip address for the nic.
 * @property subnetMask Gets or sets the mask.
 */
public data class NicIPSettingsArgs(
    public val allocationMethod: Output<Either<String, IPAddressAllocationMethod>>? = null,
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<List<String>>? = null,
    public val ipAddress: Output<String>? = null,
    public val subnetMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.NicIPSettingsArgs.builder()
            .allocationMethod(
                allocationMethod?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipAddress(ipAddress?.applyValue({ args0 -> args0 }))
            .subnetMask(subnetMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NicIPSettingsArgs].
 */
@PulumiTagMarker
public class NicIPSettingsArgsBuilder internal constructor() {
    private var allocationMethod: Output<Either<String, IPAddressAllocationMethod>>? = null

    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<List<String>>? = null

    private var ipAddress: Output<String>? = null

    private var subnetMask: Output<String>? = null

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("safmqrkxfdasflks")
    public suspend fun allocationMethod(`value`: Output<Either<String, IPAddressAllocationMethod>>) {
        this.allocationMethod = value
    }

    /**
     * @param value Gets or sets the dns servers.
     */
    @JvmName("pylnvpespspanhwi")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("jyxpbrwqncbpflir")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the dns servers.
     */
    @JvmName("eohnhtpmnkmgyrsd")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Gets or sets the gateway.
     */
    @JvmName("pujccqrdnowuativ")
    public suspend fun gateway(`value`: Output<List<String>>) {
        this.gateway = value
    }

    @JvmName("aqjeycpdoyeumwlo")
    public suspend fun gateway(vararg values: Output<String>) {
        this.gateway = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the gateway.
     */
    @JvmName("etmlwsjmtxpuekuh")
    public suspend fun gateway(values: List<Output<String>>) {
        this.gateway = Output.all(values)
    }

    /**
     * @param value Gets or sets the ip address for the nic.
     */
    @JvmName("qipbygwmnwjcbrww")
    public suspend fun ipAddress(`value`: Output<String>) {
        this.ipAddress = value
    }

    /**
     * @param value Gets or sets the mask.
     */
    @JvmName("uxgkkgxodsyhxkra")
    public suspend fun subnetMask(`value`: Output<String>) {
        this.subnetMask = value
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("ykcbdohjmusqufns")
    public suspend fun allocationMethod(`value`: Either<String, IPAddressAllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("cocfhekxlrsqjqwq")
    public fun allocationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAddressAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the nic allocation method.
     */
    @JvmName("dwpxluthqkdusapg")
    public fun allocationMethod(`value`: IPAddressAllocationMethod) {
        val toBeMapped = Either.ofRight<String, IPAddressAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allocationMethod = mapped
    }

    /**
     * @param value Gets or sets the dns servers.
     */
    @JvmName("xqrhpylgvaeullmn")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Gets or sets the dns servers.
     */
    @JvmName("rbvnusygnrwjrptk")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Gets or sets the gateway.
     */
    @JvmName("orvowfhsrdohcrda")
    public suspend fun gateway(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param values Gets or sets the gateway.
     */
    @JvmName("bmdkrgfsontbqrgs")
    public suspend fun gateway(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Gets or sets the ip address for the nic.
     */
    @JvmName("knphnvagklgotlyu")
    public suspend fun ipAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddress = mapped
    }

    /**
     * @param value Gets or sets the mask.
     */
    @JvmName("owsdgoprdirumixb")
    public suspend fun subnetMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMask = mapped
    }

    internal fun build(): NicIPSettingsArgs = NicIPSettingsArgs(
        allocationMethod = allocationMethod,
        dnsServers = dnsServers,
        gateway = gateway,
        ipAddress = ipAddress,
        subnetMask = subnetMask,
    )
}
